@@ -1,4 +1,7 @@
+#!/usr/bin/env python3
+import argparse
 import logging
+from textwrap import dedent
 
 import sys
 from pathlib import Path
@@ -14,6 +17,19 @@ from . import ListboxControl, CheckboxFrame
 from . import var, spec, fn
 from .model import CP, BindingGlobal, Timeout, TimeoutIdle, Interval, RateLimiter, FileType, FileTypes, Justification, WindowState
 
+# Automatic Tab Completion
+if __debug__:
+    import shtab
+else:
+    # Production Wrapper (keep the API)
+    class shtab:  # type: ignore
+        # Global Markers
+        FILE = None
+        DIRECTORY = None
+
+        # API
+        def add_argument_to(self, *args, **kwargs):
+            pass
 
 logger = logging.getLogger(__name__)
 
@@ -447,7 +463,8 @@ class NB_Child_RateLimiter(FrameUnlabelled):
 
     def setup_widgets(self):
         self.txt_lbl = Label(self, label='Now')
-        self.txt = Entry(self, justify=CP.center, readonly=True, width=30)
+        self.txt = Entry(self, readonly=True,
+                         justify=CP.center, width=30)
         self.hit_lbl = Label(self, label='Hit me Hard!\nCount will only change once per second.\nThe timings are not perfect.')
         self.buttonHit = Button(self, label='HIT')
         self.stateRL = Checkbox(self, label='Rate Limited?', readonly=True)
@@ -574,6 +591,12 @@ class NB_Complex_CheckboxList(CheckboxFrame):
                 '%d' % n: 'Check #%d' % n
                 for n in range(0, 15, 3)
             },
+            'label': 'TopLevel Label',
+            'labelsCheckboxes': {
+                # See the order of label keys
+                '0': 'CB #0',
+                ('0',): 'CheckBox #0',
+            },
             'layoutCheckboxes': '2x3',
         })
         super().__init__(*args, **kwargs)
@@ -582,21 +605,29 @@ class NB_Complex_CheckboxList(CheckboxFrame):
 class NB_Complex_CheckboxNested(CheckboxFrame):
     def __init__(self, *args, **kwargs):
         kwargs.update({
-            'layout': 'H1,x',
+            'layout': 'H1,2,x',
+            'hasButtons': [  # Custom buttons, changes the layout above
+                CheckboxFrame.IButton('enable', 'Enable ALL',
+                                      onClickSetAll=True),
+                CheckboxFrame.IButton('disable', 'Disable ALL',
+                                      onClickSetAll=False),
+                CheckboxFrame.IButton('other', 'Other',
+                                      self.onClickOther),
+            ],
             'stateCheckboxes': {
                 **{
                     'N1(%d)' % nn: {
-                        'N2%d_%d' % (nn, nnn): 'N2(%d|%d)' % (nn, nnn)
+                        'N2(%d)' % nnn: 'N2(%d|%d)' % (nn, nnn)
                         for nnn in range(2)
                     }
                     for nn in range(3)
                 },
                 **{
-                    'NN1': {
-                        'NN2_0': 'NN2(0)',
+                    'NN1(0)': {
+                        'NN2': 'NN2(0|0)',
                         **{
                             'NN2(%d)' % N: {
-                                'NN3%d_%d' % (N, NN): 'NN3(%d|%d)' % (N, NN)
+                                'NN3(%d)' % NN: 'NN3(0|%d|%d)' % (N, NN)
                                 for NN in range(3)
                             }
                             for N in range(1, 2 + 1)
@@ -604,16 +635,27 @@ class NB_Complex_CheckboxNested(CheckboxFrame):
                     },
                 },
             },
-            'layoutCheckboxes': [tk.HORIZONTAL, tk.VERTICAL, tk.VERTICAL],
+            'stateDefault': True,
+            'layoutCheckboxes': [tk.HORIZONTAL, tk.VERTICAL, 'R1,x'],
+            'labelsCheckboxes': {
+                ('NN1(0)',): 'NN1 [[0]]',
+                **{
+                    ('N1(%d)' % nn,): 'N1 [[%d]]' % nn
+                    for nn in range(2)
+                }
+            },
             'traceFn': self.onCheckboxClick,
         })
         super().__init__(*args, **kwargs)
 
-    def onCheckboxClick(self, what):
+    def onCheckboxClick(self, *what):
         def onCheckboxClick(var, etype):
-            logger.debug('Trace: %s [%s]', what, var.get())
+            logger.debug('Trace: %s [%s]', ' » '.join(what), var.get())
         return onCheckboxClick
 
+    def onClickOther(self):
+        logger.debug('Click "Other" @ %s', self)
+
 
 class NB_Complex(Notebook):
     def setup_tabs(self):
@@ -1011,12 +1053,25 @@ class RW(RootWindow):
 
 
 def entrypoint():
-    import argparse
-    parser = argparse.ArgumentParser(description='Showcase for tkmilan module')
-
+    '''
+    Main entrypoint to be configured
+    '''
     # ./showcase-images
     default_images = Path(__file__).parent / 'showcase-images'
 
+    parser = argparse.ArgumentParser(
+        formatter_class=argparse.RawDescriptionHelpFormatter,
+        description=dedent('''
+        Showcase for tkmilan module
+        '''),
+        # epilog=f'Version {PROJECT_VERSION}',
+    )
+    # Automatic Tab Completion
+    # - Mark certain arguments with:
+    #   - `parser.add_argument(...).complete = shtab.FILE`: Complete file names
+    #   - `parser.add_argument(...).complete = shtab.DIRECTORY`: Complete directory names
+    shtab.add_argument_to(parser, '--generate-shtab-completion', help=argparse.SUPPRESS)
+
     # parser.add_argument('--version', action='version', version=PROJECT_VERSION)
     parser.add_argument('-v', '--verbose', dest='loglevel',
                         action='store_const', const=logging.DEBUG, default=logging.INFO,
@@ -1028,6 +1083,7 @@ def entrypoint():
     parser.add_argument('--no-images', action='store_const',
                         dest='images', const=None,
                         help='Do not load any images')
+
     args = parser.parse_args()
 
     # Logs
@@ -1049,7 +1105,9 @@ def entrypoint():
     logger.debug('         /2: %r', r.size_screen.reduce(2))
     r.mainloop()
 
+    return 0
+
 
 if __name__ == '__main__':
     import sys
-    sys.exit(entrypoint() or 0)
+    sys.exit(entrypoint())
