@@ -5,6 +5,7 @@ import logging
 import warnings
 import typing
 import math
+import sys
 
 import tkinter as tk
 
@@ -140,14 +141,39 @@ def do(layout_input: typing.Optional[str], amount: int) -> typing.Tuple[typing.O
                 args = iter(logged_args)  # ... and return a new iterator
         except Exception as e:
             if __debug__:
-                warnings.warn('Weird Layout: %s' % layout_input, stacklevel=5)
+                warnings.warn('Weird Layout: %s' % layout_input, stacklevel=6)
                 logger.warning('Layout Exception: %s', e)
+                sys.exit(100)
             args = []
     return layout, args
 
 
+# TODO: Return a generator?
+def gnested(nlayout: typing.Union[str, typing.Sequence[str]]) -> typing.Tuple[str, typing.Union[str, typing.Sequence[str]]]:
+    '''Calculate the current and next layout, for nested widgets.
+
+    Args:
+        nlayout: The current layout.
+
+    Returns:
+        A tuple of ``this_layout`` (the current layout), and ``next_layout`` (the next layout level).
+        ``next_layout`` is the input for this function on the next level.
+    '''
+    this_layout: str
+    next_layout: typing.Union[str, typing.Sequence[str]]
+    if isinstance(nlayout, str):
+        this_layout = next_layout = nlayout
+    else:
+        if len(nlayout) > 0:
+            this_layout = nlayout[0]
+            next_layout = nlayout[1:]
+        else:
+            this_layout = next_layout = AUTO
+    return this_layout, next_layout
+
+
 if __name__ == '__main__':
-    import sys
+    # import sys
     import argparse
     parser = argparse.ArgumentParser(description='tkmilan: Auto Layout')
     parser.add_argument('-v', '--verbose', dest='loglevel',
