@@ -5,10 +5,10 @@ used externally.
 If useful, they should be exposed as methods.
 '''
 import logging
+import warnings
 import typing
 import sys
 import math
-from functools import wraps
 from textwrap import dedent
 from pathlib import Path
 
@@ -126,16 +126,25 @@ def configure(master: 'mixin.ContainerWidget',
                 master.columnconfigure(c, **kwargs)  # type: ignore  # Invalid Types
 
 
+# TODO: Remove on v0.18
 def generate_trace(variable: tk.Variable, function: typing.Callable, **kwargs):
-    '''Generate an internal trace callback.
+    '''DEPRECATED. See `tkmilan.var.trace`.'''
+    raise NotImplementedError('DEPRECATED')
 
-    The function generated here should be attached to the ``Tk`` event.
+
+def state_ignore(*toignore: 'mixin.MixinWidget'):
+    '''Ignore some subwidgets for container widgets.
+
+    Mark those widgets with the `ignoreContainerState
+    <mixin.MixinWidget.ignoreContainerState>` flag. Should be called as part of
+    the `setup_widgets <mixin.ContainerWidget.setup_widgets>` function in
+    `container widgets <mixin.ContainerWidget>`.
     '''
-    @wraps(function)
-    def wrapper(name: str, index: typing.Any, etype: model.TraceModeT):  # "Real" tk function
-        assert isinstance(name, str) and isinstance(etype, str)
-        return function(variable, etype, **kwargs)
-    return wrapper
+    assert len(toignore) > 0, 'Nothing to ignore'
+    for w in toignore:
+        if w.ignoreContainerState is True:
+            warnings.warn(f'Already ignored: {w}', stacklevel=2)
+        w.ignoreContainerState = True
 
 
 def vname(variable: tk.Variable) -> str:
