@@ -369,7 +369,9 @@ class Direction(enum.Enum):
         size = rows * cols
         amount = amount or size
         if amount > size:
-            raise ValueError('Too many widgets in too few locations')
+            raise ValueError(f'Too many widgets in too few locations: {amount} > {size}')
+        if amount == 0:
+            raise ValueError(f'Too few widgets in too much locations: {amount}')
         extra_size = size - amount
         if self.dR != 0 and extra_size >= rows:
             raise ValueError('Too few widgets for this grid: empty columns')
@@ -451,9 +453,11 @@ class Direction(enum.Enum):
             logger_layout.debug('- Sizes : A%d O%d = %d', asize, osize, asize * osize)
         # assert isinstance(amount, int)
         if amount > size:
-            raise ValueError('Too many widgets for these amounts')
+            raise ValueError(f'Too many widgets for these amounts: {amount} > {size}')
         elif amount < size:
-            raise ValueError('Too few widgets for these amounts')
+            raise ValueError(f'Too few widgets for these amounts: {amount} < {size}')
+        elif osize == 0:
+            raise ValueError(f'Too few widgets in too much locations: {amount}')
         for idx, this_amount in enumerate(amounts):
             this_width = osize // this_amount
             for other in range(0, osize, this_width):
