@@ -117,7 +117,10 @@ class Test_Direction_Multiple(unittest.TestCase):
     ROTTEN = (  # Direction, amounts, amount
         # Non-Integer amount to distribute
         (None, (None, None), 3),
-        (None, (None, 1, None), 4),
+        (None, (None, 1, None), 4),  # TODO: This could be supported
+        # Bad Distributions
+        # - Not enough widgets to distribute: `$1,3,x`
+        (None, (1, 3, None), 4),
     )
 
     def runTest(self):
