@@ -21,15 +21,15 @@ class Test_LTML(unittest.TestCase):
     def test_simple(self):
         html_string = 'Text<a>Link</a>More Text<br/>Line Break above<a href="clean">Clean Link</a>S1<span>S2</span>S3'
         golden = [
-            model.TextElement_span(text='Text'),
-            model.TextElement_span(text='Link', tag='a', tags=['a::0']),
-            model.TextElement_span(text='More Text'),
+            model.TextElementInline(text='Text'),
+            model.TextElementInline(text='Link', tag='a', tags=['a::0']),
+            model.TextElementInline(text='More Text'),
             model.TextElement_br(),
-            model.TextElement_span(text='Line Break above'),
-            model.TextElement_span(text='Clean Link', tag='a', tags=['a-clean', 'a::1']),
-            model.TextElement_span(text='S1'),
-            model.TextElement_span(text='S2', tag='span', tags=['span::0']),
-            model.TextElement_span(text='S3'),
+            model.TextElementInline(text='Line Break above'),
+            model.TextElementInline(text='Clean Link', tag='a', tags=['a-clean', 'a::1']),
+            model.TextElementInline(text='S1'),
+            model.TextElementInline(text='S2', tag='span', tags=['span::0']),
+            model.TextElementInline(text='S3'),
         ]
 
         result = parser.parse_LTML(html_string)
@@ -38,7 +38,7 @@ class Test_LTML(unittest.TestCase):
     def test_data(self):
         html_string = dedent('''<span data-one="1" data-two="2">Text</span>''')
         golden = [
-            model.TextElement_span(text='Text', tag='span', tags=['span::0'], data={
+            model.TextElementInline(text='Text', tag='span', tags=['span::0'], data={
                 'one': '1',
                 'two': '2',
             }),
@@ -51,7 +51,7 @@ class Test_LTML(unittest.TestCase):
         html_string = 'Some Text\nLine Break above'
         with self.assertWarns(Warning):
             golden = [
-                model.TextElement_span(text='Some Text\nLine Break above'),
+                model.TextElementInline(text='Some Text\nLine Break above'),
             ]
 
             result = parser.parse_LTML(html_string)
@@ -60,9 +60,9 @@ class Test_LTML(unittest.TestCase):
     def test_br(self):
         html_string = dedent('''Text<br/>Text''')
         golden = [
-            model.TextElement_span(text='Text'),
+            model.TextElementInline(text='Text'),
             model.TextElement_br(),
-            model.TextElement_span(text='Text'),
+            model.TextElementInline(text='Text'),
         ]
         result = parser.parse_LTML(html_string)
 
